@@ -206,7 +206,7 @@ add_grlearn_acl(struct role_acl *role)
 	return;
 }
 
-void add_fulllearn_admin_acl(void)
+static void add_fulllearn_admin_acl(void)
 {
 	add_role_acl(&current_role, gr_strdup("admin"), role_mode_conv("sA"), 0);
 	add_proc_subject_acl(current_role, "/", proc_subject_mode_conv("aorvk"), 0);
@@ -259,26 +259,32 @@ void add_rolelearn_acl(void)
 	return;
 }
 
-static void ipc_sig(int sig)
-{
-        signal(sig, SIG_IGN);
-
-	return;
-}
-
 void start_grlearn(char *logfile)
 {
 	pid_t pid;
+	int fds[2];
+	int ret;
 
-	signal(SIGUSR1, ipc_sig);
+	ret = pipe(fds);
+	if (ret == -1) {
+		fprintf(stderr, "Error creating pipe.\n");
+		exit(EXIT_FAILURE);
+	}
 
 	pid = fork();
 
 	if (!pid) {
+		close(fds[0]); // close read end
 		execl(GRLEARN_PATH, GRLEARN_PATH, logfile, NULL);
 		exit(EXIT_FAILURE);
 	} else if (pid > 0) {
-		pause(); // wait for child to send us SIGUSR1
+		char b;
+		close(fds[1]); // close write end
+		read(fds[0], &b, 1);
+		close(fds[0]);
+	} else {
+		fprintf(stderr, "Error starting grlearn.\n");
+		exit(EXIT_FAILURE);
 	}
 
 	return;
