@@ -89,6 +89,47 @@ check_subjects(struct role_acl *role)
 	return errs_found;
 }
 
+static int
+check_learning(struct role_acl *role)
+{
+	struct proc_acl *tmp;
+	struct proc_acl *def_acl;
+	unsigned int errs_found = 0;
+
+	def_acl = role->root_label;
+	if (!def_acl)
+		return 0;
+	if (gr_learn)
+		return 0;
+
+	if (!gr_learn && role->roletype & GR_ROLE_LEARN) {
+		fprintf(stderr,
+			"Warning: You have enabled learning on the role "
+			"%s.  You have not used -L on the command "
+			"line however.  If you wish to use learning "
+			"on this role, use the -L argument to gradm.  "
+			"Otherwise, remove the learning flag on this role.\n",
+			role->rolename);
+		errs_found++;
+	}
+
+	for_each_subject(tmp, role) {
+	    if (!gr_learn && (tmp->mode & (GR_LEARN | GR_INHERITLEARN))) {
+			fprintf(stderr,
+				"Warning: You have enabled some form of "
+				"learning on the subject for %s in role "
+				"%s.  You have not used -L on the command "
+				"line however.  If you wish to use learning "
+				"on this subject, use the -L argument to gradm.  "
+				"Otherwise, remove the learning flag on this subject.\n",
+				tmp->filename, role->rolename);
+		errs_found++;
+	    }
+	}
+
+	return errs_found;
+}
+
 static void
 check_default_objects(struct role_acl *role)
 {
@@ -387,9 +428,6 @@ analyze_acls(void)
 	}
 
 	for_each_role(role, current_role) {
-		if (role->roletype & GR_ROLE_SPECIAL)
-			continue;
-
 		def_acl = role->root_label;
 		if (!def_acl) {
 			fprintf(stderr, "There is no default subject for "
@@ -402,7 +440,13 @@ analyze_acls(void)
 		}
 
 		check_default_objects(role);
+
+		/* non-critical warnings aren't issued for special roles */
+		if (role->roletype & GR_ROLE_SPECIAL)
+			continue;
+
 		errs_found += check_subjects(role);
+		errs_found += check_learning(role);
 
 		chk.type = CHK_FILE;
 		chk.u_modes = GR_FIND;
@@ -637,17 +681,17 @@ analyze_acls(void)
 		errs_found += check_path_env(role, def_acl);
 		errs_found += check_lib_paths(role, def_acl);
 		errs_found += check_lilo_conf(role, def_acl);
+	}
+	/* end of per-role checks */
 
-		errs_found += handle_notrojan_mode();
-
-		if (errs_found) {
-			printf("There were %d holes found in your RBAC "
-			       "configuration.  These must be fixed before the "
-			       "RBAC system will be allowed to be enabled.\n",
-			       errs_found);
-			exit(EXIT_FAILURE);
-		}
+	errs_found += handle_notrojan_mode();
 
+	if (errs_found) {
+		printf("There were %d holes found in your RBAC "
+		       "configuration.  These must be fixed before the "
+		       "RBAC system will be allowed to be enabled.\n",
+		       errs_found);
+		exit(EXIT_FAILURE);
 	}
 
 	return;
